ClampedInteraction
==================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ClampedInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ClampedInteraction.entity_shape
      ~ClampedInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~ClampedInteraction.forward

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: forward
